@@ -26,7 +26,7 @@ and http://janne-pekkala.blogspot.com/"""
     p.maintainer="Yabba"
     p.mail="yabbapappa@gmail.com"
     p.url="http://janne-pekkala.blogspot.com"
-    p.depends = "python2.5, python2.5-qt4-gui, python2.5-qt4-core, python-osso, python-gst0.10, lirc"
+    p.depends = "python2.5, python2.5-qt4-gui, python2.5-qt4-core, python-osso, python-gst0.10, lirc, zenity"
     p.section="user/utilities"
     p.icon = "/home/user/MyDocs/pykake/pykake.png"
     p.arch="all"                #should be all for python, any for all arch
@@ -49,7 +49,9 @@ and http://janne-pekkala.blogspot.com/"""
     /etc/init.d/lirc start
     /etc/init.d/lirc reload
     /etc/init.d/lirc stop
-    /usr/bin/gtk-update-icon-cache -f /usr/share/icons/hicolor"""
+    /usr/bin/gtk-update-icon-cache -f /usr/share/icons/hicolor
+    run-standalone.sh zenity --info --text="If this is first time you install pyKake, it is possible that device reboot is needed before pyKake can send infrared signals. To test this, put your camera in live view mode, aim the device to the camera and press shutter button in pyKake, if you don't se light plinking in infrared port, you need to reboot."
+    """
 
     # Post remove script
     p.postremove="""#!/bin/sh
@@ -60,11 +62,15 @@ and http://janne-pekkala.blogspot.com/"""
     # chmod +x /usr/bin/mclock.py""" #Set here your pre install script
     # p.preremove="""#!/bin/sh
     # chmod +x /usr/bin/mclock.py""" #Set here your pre remove script
-    version = "0.7.1"           #Version of your software, e.g. "1.2.0" or "0.8.2"
-    build = "2"                 #Build number, e.g. "1" for the first build of this version of your software. Increment for later re-builds of the same version of your software.
+    version = "0.7.2"           #Version of your software, e.g. "1.2.0" or "0.8.2"
+    build = "1"                 #Build number, e.g. "1" for the first build of this version of your software. Increment for later re-builds of the same version of your software.
 
     # Text with changelog information to be displayed in the package "Details" tab of the Maemo Application Manager
-    changeloginformation = """ Fix the rootsh bug there was and gives some startup speed too. """
+    changeloginformation = """ 
+    - Replacing reboot notification from startup with zenity notification in post-install (zenity new in dependencies).
+    - New help dialog.
+    - Long text entrys moved to separate files.
+    - Added some prints to ease bugtracking """
 
     dir_name = "src"            #Name of the subfolder containing your package source files (e.g. usr\share\icons\hicolor\scalable\myappicon.svg, usr\lib\myapp\somelib.py). We suggest to leave it named src in all projects and will refer to that in the wiki article on maemo.org
     #Thanks to DareTheHair from talk.maemo.org for this snippet that recursively builds the file list
