@@ -3,74 +3,14 @@
 
 """ This is a Qt Gui file for pyKake. """
 
-LICENSE = """
-This program is free software: you can redistribute it and/or
-modify it under the terms of the GNU General Public License as
-published by the Free Software Foundation, either version 3 of
-the License, or (at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-PURPOSE.  See the GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public
-License along with this program.If not, see:
-http://www.gnu.org/licenses."""
-
-SETTINGS = """
-In settings you can change between camera manufacturers and 
-interval of sound notice in Bulb timer. Sound notice is played
-when selected amount of time is ellapsed, default setting of 
-this is 30 seconds. You can also turn restart notify in start 
-up on and off.
-"""
-
-BASIC = """
-In this mode you can take photos, just click the "Shutter" button.
-For Canon, there is also "Activate/Deactivate 2sec mode" button, 
-when it is activated, photos with 2 seconds interval can be taken
-(in other manufacturers you had to select this function from camera).
-"""
-
-BULB = """
-This is front end to take photos with Bulb. As default timer will 
-count up and it will play sound notify when selected time is elapsed. 
-You can also set it counting down and it will play sound when time is
-up.
-
-The app won't send the end command to the camera automatically 
-so you had to do it yourself, with Bulb off button. Timer don't 
-understand 2 seconds delay, so you must to count it by yourself.
-"""
-
-VIEWER = """
-Viewer is only available for Olympus. You can use this to remote
-control your camera in View mode to zoom and change photos. This 
-is handy if you watch pictures in TV.
-"""
-
-REMOTES = """
-Currently pyKake support following remotes from manufacturers:
-Canon: RC-1
-Nikon: ML-L3
-Olympus: RM-1
-Pentax: RC-F
-Samsung: RC-F (Cameras are compatible with Pentax)
-"""
-
-MESSAGE = """
-If this is first time you use pyKake after install, it is possible that you need to restart the device before pyKake can send infrared signals. To test this, put your camera in live view mode, aim the device to the camera and press shutter button in pyKake, if you don't se light plinking in infrared port, you need to restart.
-"""
-
 APP_TITLE="pyKake"
-APP_VERSION="0.7.1"
+APP_VERSION="0.7.2"
 LOGO = '/opt/pykake/pykake.png'
 BUGTRACKER= "http://talk.maemo.org/showthread.php?t=50204"
 
 import sys
 
-""" Crazy hack to instantiate QApplication in PR 1.3 (From Dropn900 by Jonne Nauha)."""
+""" Crazy hack to instantiate QApplication in PR 1.3 (From DropN900 by Jonne Nauha)."""
 from PyQt4.QtGui import QApplication
 app = QApplication(sys.argv)
 
@@ -115,42 +55,47 @@ sizePolicy = QSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding) # Size po
 
 class MainWindow(QMainWindow): # Class for main application
 	def __init__(self):
+		print "Intializing Main..."
 		QMainWindow.__init__(self, None)		 # Intializing the main window
 		self.mapper = QSignalMapper() # Intializing the Signal mapper for the program
 		
-		# Reboot notification in case of first run.
-		helpfile = QVariant(MiscFunctions().loadQSettings("settings/help_show", True)).toBool()
-		if helpfile != False:
-			QMessageBox.question(self, 'Important', MESSAGE, QMessageBox.Ok)
-		
+		# Collecting settings for app, if this is first run
+		print "Check that settings has been set..."
+		if CURRENT_REMOTETYPE == "None" or TIME2BEEB == "None":
+			self.settingsDialog()
+			
 		self.resize(800, 480)
+		print "Reading style..."
 		self.setStyleSheet(MiscFunctions().readFile(styleFile))
 		self.setWindowTitle("%s %s" %(APP_TITLE, APP_VERSION))
 		
 		# Creating menu buttons:
-		self.mbSettings = QAction('Settings', self)
-		self.mbSettings.setObjectName("menuButton")
-		self.connect(self.mbSettings, SIGNAL('triggered()'), self.settingsDialog)
-		
-		self.mbAbout = QAction('About', self)
-		self.connect(self.mbAbout, SIGNAL('triggered()'), self.aboutDialog)
-		
-		self.mbHelp = QAction('Help', self)
-		self.connect(self.mbHelp, SIGNAL('triggered()'), self.helpDialog)
-		
-		self.mbBugger = QAction('Bugtracker', self)
-		self.connect(self.mbBugger, SIGNAL("clicked()"), self.mapper, SLOT("map()"))
-		self.mapper.setMapping(self.mbBugger, "bugger")
-		
-		# Creating menu
-		menubar = self.menuBar()
-		mitem = menubar.addMenu('File')
-		mitem.addAction(self.mbSettings)
-		mitem.addAction(self.mbAbout)
-		mitem.addAction(self.mbHelp)
-		mitem.addAction(self.mbBugger)
+		if USEFULLSCREEN != True:
+			print "Creating menu..."
+			self.mbSettings = QAction('Settings', self)
+			self.mbSettings.setObjectName("menuButton")
+			self.connect(self.mbSettings, SIGNAL('triggered()'), self.settingsDialog)
+			
+			self.mbAbout = QAction('About', self)
+			self.connect(self.mbAbout, SIGNAL('triggered()'), self.aboutDialog)
+			
+			self.mbHelp = QAction('Help', self)
+			self.connect(self.mbHelp, SIGNAL('triggered()'), self.helpDialog)
+			
+			self.mbBugger = QAction('Bugtracker', self)
+			self.connect(self.mbBugger, SIGNAL("clicked()"), self.mapper, SLOT("map()"))
+			self.mapper.setMapping(self.mbBugger, "bugger")
+			
+			# Creating menu
+			menubar = self.menuBar()
+			mitem = menubar.addMenu('File')
+			mitem.addAction(self.mbSettings)
+			mitem.addAction(self.mbAbout)
+			mitem.addAction(self.mbHelp)
+			mitem.addAction(self.mbBugger)
 		
 		# Creating tabs and using tab widget as a Central widget
+		print "Creating tabs..."
 		self.tabs = QTabWidget()
 		self.tabs.TabShape(QTabWidget.Rounded)
 		self.tabs.addTab(self.basicMode(), "Basic") # index = 0
@@ -162,19 +107,17 @@ class MainWindow(QMainWindow): # Class for main application
 		self.connect(self.tabs, SIGNAL("currentChanged(int)"), self.onPageChange)
 		
 		self.setCentralWidget(self.tabs)
-		
-		# Collecting settings for app, if this is first run
-		if CURRENT_REMOTETYPE == "None" or TIME2BEEB == "None":
-			self.settingsDialog()
 			
 		self.buttonVisibility()
 		self.tabVisibility()
 		
 		self.connect(self.mapper, SIGNAL("mapped(const QString &)"), self.buttonClicked) # Connects signals to functions.
+		print "Main ready!"
 
 ########## Modes in tabs ##########
 
 	def basicMode(self):
+		print "Creating Basic..."
 		widget = QWidget()
 		hbox = QHBoxLayout()
 	
@@ -194,9 +137,11 @@ class MainWindow(QMainWindow): # Class for main application
 		hbox.addWidget(self.sec2mod)
 		widget.setLayout(hbox)
 		
+		print "Basic ready!"
 		return widget
 
 	def bulbMode(self):
+		print "Creating bulb..."
 		widget = QWidget()
 		
 		hbox = QHBoxLayout()
@@ -234,9 +179,11 @@ class MainWindow(QMainWindow): # Class for main application
 		hbox.addLayout(vbox, 0)
 		widget.setLayout(hbox)
 		
+		print "Bulb ready!"
 		return widget
 		
 	def timedMode(self):
+		print "Creating timed..."
 		widget = QWidget()		
 		main = QVBoxLayout()
 		
@@ -278,7 +225,7 @@ class MainWindow(QMainWindow): # Class for main application
 		self.connect(self.addTime, SIGNAL("clicked()"), self.mapper, SLOT("map()"))
 		self.mapper.setMapping(self.addTime, "addTime")
 		
-		self.photoTime = QPushButton("Add time interval\nfor photos")
+		self.photoTime = QPushButton("Add photo interval")
 		self.photoTime.setSizePolicy(sizePolicy)
 		self.connect(self.photoTime, SIGNAL("clicked()"), self.mapper, SLOT("map()"))
 		self.mapper.setMapping(self.photoTime, "photoTime")
@@ -304,9 +251,11 @@ class MainWindow(QMainWindow): # Class for main application
 		
 		widget.setLayout(main)
 		
+		print "Timed ready!"
 		return widget
 		
 	def viewerMode(self):
+		print "Creating viewer..."
 		widget = QWidget()
 		hbox = QHBoxLayout()
 		
@@ -346,9 +295,11 @@ class MainWindow(QMainWindow): # Class for main application
 		
 		widget.setLayout(hbox)
 		
+		print "Viewer ready!"
 		return widget
 
 	def systemMode(self):
+		print "Creating system..."
 		widget  = QWidget()
 
 		griddy = QGridLayout()
@@ -382,6 +333,7 @@ class MainWindow(QMainWindow): # Class for main application
 		
 		widget.setLayout(griddy)
 		
+		print "System ready!"
 		return widget
 
 ######### Timer for Bulb and Timed Modes #########
@@ -899,6 +851,7 @@ class MainWindow(QMainWindow): # Class for main application
 			print "Something wrong in buttons"
 
 	def tabEnabler(self, val): # Enabling/disabling tabs in timed and bulb mode (when process is on, tabs can't be changed).
+		print "Handling tab enbality..."
 		for i in range(self.tabs.count()):
 			if i != self.tabs.currentIndex():
 				self.tabs.setTabEnabled(i, val)
@@ -906,6 +859,7 @@ class MainWindow(QMainWindow): # Class for main application
 ####### Visibility handling #######
 
 	def buttonVisibility(self): # Button visibility, currently only sec2mod & sec2mod2 for canon
+		print "Setting button visibility..."
 		if CURRENT_REMOTETYPE != "CANON-RC1/RC5":
 			self.sec2mod.hide()
 			self.sec2mod2.hide()
@@ -914,6 +868,7 @@ class MainWindow(QMainWindow): # Class for main application
 			self.sec2mod2.show()
 
 	def tabVisibility(self):
+		print "Setting tab visibility..."
 		count = self.tabs.count() # Number of tabs, used for failsafe!
 		if USEFULLSCREEN != True and count == 5: # Removing systemMode if not fullscreen
 			self.tabs.removeTab(count-1)
@@ -1016,11 +971,6 @@ class MainWindow(QMainWindow): # Class for main application
 		elif TIME2BEEB == "0": tOff.toggle()
 		else: tOff.toggle()
 		
-		self.restartNotify = QCheckBox("Show restart notify in start up")
-		if QVariant(MiscFunctions().loadQSettings("settings/help_show", True)).toBool() == True: 
-			self.restartNotify.setChecked(True)
-		vbox.addWidget(self.restartNotify)
-		
 		self.fullscreenSelect = QCheckBox("Use Fullscreen mode\nNeeds restart to get active")
 		if USEFULLSCREEN == True: self.fullscreenSelect.setChecked(True)
 		vbox.addWidget(self.fullscreenSelect)
@@ -1038,9 +988,11 @@ class MainWindow(QMainWindow): # Class for main application
 		
 		self.dialog.setLayout(mainBox)
 		
+		print "Running settings dialog..."
 		self.dialog.exec_()
 		
 	def setSettings(self):
+		print "Save settings..."
 		global CURRENT_REMOTETYPE, TIME2BEEB, USEFULLSCREEN
 		settings = QSettings("pyKake", "pyKake")
 		
@@ -1061,9 +1013,6 @@ class MainWindow(QMainWindow): # Class for main application
 		settings.setValue("settings/beebtime", addedTime)
 		TIME2BEEB = addedTime
 		
-		if self.restartNotify.isChecked(): settings.setValue("settings/help_show", True)
-		else: settings.setValue("settings/help_show", False)
-		
 		if self.fullscreenSelect.isChecked(): settings.setValue("settings/fullscreen", True)
 		else: settings.setValue("settings/fullscreen", False)
 		
@@ -1072,6 +1021,7 @@ class MainWindow(QMainWindow): # Class for main application
 		self.buttonVisibility() # Hiding showing mod2sec buttons for canon
 		self.tabVisibility() # Handling visibility of tabs
 		
+		print "Settings saved."
 		self.dialog.accept()
 
 ########## Other dialogs ##########
@@ -1118,7 +1068,9 @@ class MainWindow(QMainWindow): # Class for main application
 		
 		lic = QWidget()
 		vbox = QVBoxLayout()
-		label = QLabel(LICENSE)
+		txt = MiscFunctions().readFile("/opt/pykake/files/license.html")
+		label = QLabel(txt)
+		label.setWordWrap(True)
 		vbox.addWidget(label)
 		lic.setLayout(vbox)
 		area2.setWidget(lic)
@@ -1128,6 +1080,7 @@ class MainWindow(QMainWindow): # Class for main application
 				
 		dialog.setLayout(mainbox)
 		
+		print "Running about dialog..."
 		dialog.exec_()
 
 	def helpDialog(self):
@@ -1137,74 +1090,40 @@ class MainWindow(QMainWindow): # Class for main application
 		
 		tabby = QTabWidget()
 		
-		# Help: Settings
+		# Help: pyKake How-To!
 		area1 = QScrollArea()
 		area1.setWidgetResizable(True)
 		area1.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding)
 		
 		settings = QWidget()
 		vbox = QVBoxLayout()
-		label = QLabel(SETTINGS)
+		txt = MiscFunctions().readFile("/opt/pykake/files/help.html")
+		label = QLabel(txt)
+		label.setWordWrap(True)
 		vbox.addWidget(label)
 		settings.setLayout(vbox)
 		area1.setWidget(settings)
-		tabby.addTab(area1, "Settings")
-		
-		# Help: Basic
+		tabby.addTab(area1, "pyKake How-To")
+	
+		# Help: Supported cameras
 		area2 = QScrollArea()
 		area2.setWidgetResizable(True)
 		area2.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding)
 		
-		basic = QWidget()
-		vbox = QVBoxLayout()
-		label = QLabel(BASIC)
-		vbox.addWidget(label)
-		basic.setLayout(vbox)
-		area2.setWidget(basic)
-		tabby.addTab(area2, "Basic")
-		
-		# Help: Bulb
-		area3 =QScrollArea()
-		area3.setWidgetResizable(True)
-		area3.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding)
-		
-		bulb = QWidget()
-		vbox = QVBoxLayout()
-		label = QLabel(BULB)
-		vbox.addWidget(label)
-		bulb.setLayout(vbox)
-		area3.setWidget(bulb)
-		tabby.addTab(area3, "Bulb")
-		
-		# Help: Viewer
-		area4 = QScrollArea()
-		area4.setWidgetResizable(True)
-		area4.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding)
-		
-		viewer = QWidget()
-		vbox = QVBoxLayout()
-		label = QLabel(VIEWER)
-		vbox.addWidget(label)
-		viewer.setLayout(vbox)
-		area4.setWidget(viewer)
-		tabby.addTab(area4, "Viewer")
-
-		# Help: Supported cameras
-		area5 = QScrollArea()
-		area5.setWidgetResizable(True)
-		area5.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding)
-		
 		supCams = QWidget()
 		vbox = QVBoxLayout()
-		label = QLabel(REMOTES)
+		txt = MiscFunctions().readFile("/opt/pykake/files/supported.html")
+		label = QLabel(txt)
+		label.setWordWrap(True)
 		vbox.addWidget(label)
 		supCams.setLayout(vbox)
-		area5.setWidget(supCams)
-		tabby.addTab(area5, "Supported cameras")
+		area2.setWidget(supCams)
+		tabby.addTab(area2, "Supported cameras")
 		
 		mainbox.addWidget(tabby)
 		dialog.setLayout(mainbox)
 		
+		print "Running help dialog..."
 		dialog.exec_()
 		
 ############ Other classes ############
@@ -1218,19 +1137,25 @@ class ButtonFunctions:
 class MiscFunctions:
 	def controlLircd(self, cmd): # Starting and stoping lirc
 		arg = ["sudo","/etc/init.d/lirc", cmd]
-		lircing = subprocess.Popen(arg)
+		lircing = subprocess.Popen(arg, stdout=subprocess.PIPE)
+		output = lircing.stdout.readline()
+		print "Lirc output: %s" %output
 		lircing.wait()
 
-	def loadQSettings(self, path, default): # Reading QSettings
+	def readQSettings(self, path, default): # Reading QSettings
+		print "Reading QSettings..."
 		settings = QSettings("pyKake", "pyKake")
 		value = settings.value(path, default) # path == location of the value | default == default value (failback)
 		return value
 	
 	def exitFunction(self): # Exiting the application
+		print "Exit..."
 		MiscFunctions().controlLircd("stop")
+		print "Bye Bye!"
 		sys.exit()
 	
 	def readFile(self, fileName):
+		print "Reading file..."
 		file = QFile(fileName)
 		
 		if not file.open(QFile.ReadOnly | QFile.Text):
@@ -1241,10 +1166,11 @@ class MiscFunctions:
 		return text
 
 	def loadSettings(self): # Reloading settings from conf file at /home/user/.config/pyKake/pyKake.conf
-		 global CURRENT_REMOTETYPE, TIME2BEEB, USEFULLSCREEN
-		 CURRENT_REMOTETYPE = QVariant(MiscFunctions().loadQSettings("settings/camera", "None")).toString()
-		 TIME2BEEB = QVariant(MiscFunctions().loadQSettings("settings/beebtime", "None")).toString()
-		 USEFULLSCREEN = QVariant(MiscFunctions().loadQSettings("settings/fullscreen", True)).toBool()
+		print "Settingsloader..."
+		global CURRENT_REMOTETYPE, TIME2BEEB, USEFULLSCREEN
+		CURRENT_REMOTETYPE = QVariant(self.readQSettings("settings/camera", "None")).toString()
+		TIME2BEEB = QVariant(self.readQSettings("settings/beebtime", "None")).toString()
+		USEFULLSCREEN = QVariant(self.readQSettings("settings/fullscreen", True)).toBool()
 		 
 class player (QThread):
 	def run(self):
@@ -1261,7 +1187,7 @@ class digitalCamera: # This is class where commands from GUI are translated read
 		self.remote(cmd)
 
 	def canon(self):
-		global mod2sec
+		# global mod2sec
 		if mod2sec == True:
 			cmd = "2S"
 		else:
@@ -1290,13 +1216,18 @@ class digitalCamera: # This is class where commands from GUI are translated read
 
 	# COMMANDING INFRA RED
 	def remote(self, code):
+		print "Shooting..."
 		remote = CURRENT_REMOTETYPE
 		arg = ["/usr/bin/irsend", "send_once", remote, code]
-		shoot = subprocess.Popen (arg, stdin = subprocess.PIPE)
+		shoot = subprocess.Popen (arg, stdin = subprocess.PIPE, stdout = subprocess.PIPE)
+		output = shoot.stdout.readline()
 		shoot.stdin.close()
+		if output != "":
+			print "irsend error: %s" %output
 		shoot.wait()
 
 	def bulbPatchPentax(self, state):
+		print "Shooting Pentax"
 		remote = CURRENT_REMOTETYPE
 		code = "Capture"
 		if state == "start":
@@ -1306,8 +1237,11 @@ class digitalCamera: # This is class where commands from GUI are translated read
 		else:
 			directive = "send_once"
 		arg = ["/usr/bin/irsend", directive, remote, code]
-		shoot = subprocess.Popen (arg, stdin = subprocess.PIPE)
+		shoot = subprocess.Popen (arg, stdin = subprocess.PIPE, stdout = subprocess.PIPE)
+		output = shoot.stdout.readline()
 		shoot.stdin.close()
+		if output != "":
+			print "irsend error: %s" %output
 		shoot.wait()
 
 	################################################################################################
@@ -1316,17 +1250,22 @@ class digitalCamera: # This is class where commands from GUI are translated read
 ####### Running the Application #######
 
 #app = QApplication(sys.argv) # Currently out of use (since v. 0.7.1), because Pr 1.3 causing problems at the moment (2.11.2010).
+print "Loading settings..."
 MiscFunctions().loadSettings()
+print "Starting Lirc..."
 MiscFunctions().controlLircd("start")
 
+print "Calling Main window..."
 main = MainWindow()
 
-
-if USEFULLSCREEN == True: 
+if USEFULLSCREEN == True:
+	print "Showing window: Fullscreen"
 	main.showFullScreen()
 else:
+	print "Showing window: Normal"
 	main.show()
 
+
+print "Executing the app..."
 app.exec_()
 MiscFunctions().exitFunction()
-
